@@ -8,6 +8,9 @@ jumbled_words = random.shuffle(words)
 
 def random_answer(daily: bool):
     """Picks a random answer every day."""
+
+    UNIX_reference = 1645678800
+    jumbled_words = random.shuffle(words)
     if daily == True:
         UNIX = dt.now().timestamp()
         iteration = int(math.floor((UNIX - UNIX_reference)/86400000))
